# -*- coding: utf-8 -*-
require "yaml"
require "json"
require "girls_bar/command/confirm"
require "girls_bar/command/input"
require "girls_bar/command/redirect"
require "girls_bar/command/restart"
require "girls_bar/command/script"
require "girls_bar/constants"
require "girls_bar/data"
require "girls_bar/entry"
require "girls_bar/filter"
require "girls_bar/helper"
require "girls_bar/router"
require "girls_bar/settings"
require "girls_bar/version"

module GirlsBar
  def self.run(path)
    resource = load_resource(path)
    GirlsBar::Settings.setup resource["config"]
    GirlsBar::Entry.setup resource["entry"]
    GirlsBar::Data.setup
    GirlsBar::Router.start
  end

  def self.generate(format)
    dump_resource(format)
  end

  private
  def self.load_resource(path)
    begin
      raise "File Does Not Exist" unless FileTest.exist?(path)
      case File.extname(path)
      when ".yml"
        resource = YAML.load_file path
      when ".json"
        resource = JSON.load open(path)
      else
        raise "Invalid File Extension"
      end
    rescue => e
      GirlsBar::Helper.set_color(:white, :on_red) { puts e.message }
    end
  end

  def self.dump_resource(format=nil)
    data = YAML.load GirlsBar::TEMPLATE
    if format == "json"
      filename = "tequila.json"
      open(filename, "w") {|io| io.write JSON.pretty_generate data }
    else
      filename = "tequila.yml"
      open(filename, "w") {|io| io.write YAML.dump data }
    end
    GirlsBar::Helper.set_color(:blue) { puts "...Generated #{filename}" }
  end
end
