# -*- coding: utf-8 -*-
module GirlsBar
  class Entry
    class << self
      def setup(resource)
        @data = []
        resource.each_pair do |res|
          @data << GirlsBar::Entry.new(res)
        end
      end

      def all
        @data
      end

      def first
        @data.first
      end
    end

    attr :id

    def initialize(resource)
      @id = GirlsBar::Filter.to_id resource[0]
      @commands = []
      register_commands resource[1]
    end

    def execute
      @commands.map(&:execute)
    end

    private
    def register_commands(resource)
      add_command_script resource
      add_command_input resource
      add_command_confirm resource
      add_command_redirect resource
      add_command_restart resource
    end

    def add_command_script(resource)
      return if resource["script"].nil?
      @commands << GirlsBar::Command::Script.new(resource["script"])
    end

    def add_command_input(resource)
      return if resource["input"].nil?
      @commands << GirlsBar::Command::Input.new(resource["input"])
    end

    def add_command_confirm(resource)
      return if resource["confirm"].nil? || !resource["input"].nil?
      @commands << GirlsBar::Command::Confirm.new(resource["confirm"])
    end

    def add_command_redirect(resource)
      return if resource["redirect_to"].nil?
      @commands << GirlsBar::Command::Redirect.new(resource["redirect_to"])
    end

    def add_command_restart(resource)
      return unless resource["input"].nil? && resource["confirm"].nil?
      @commands << GirlsBar::Command::Restart.new
    end
  end

  class Selection
    attr :key, :label, :link

    def initialize(key, label, link)
      @key   = GirlsBar::Filter.to_id key
      @label = label
      @link  = GirlsBar::Filter.to_id link
    end
  end
end
